==> vala-0.3.2.tar.gz: vala-0.3.2/vala/valaforstatement.h <==
/* valaforstatement.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAFORSTATEMENT_H__
#define __VALA_VALAFORSTATEMENT_H__

#include <glib.h>
#include <glib-object.h>
#include <gee/collection.h>
#include <vala/valacodenode.h>
#include <vala/valastatement.h>

G_BEGIN_DECLS


#define VALA_TYPE_FOR_STATEMENT (vala_for_statement_get_type ())
#define VALA_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatement))
#define VALA_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))
#define VALA_IS_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FOR_STATEMENT))
#define VALA_IS_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FOR_STATEMENT))
#define VALA_FOR_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))

typedef struct _ValaForStatementPrivate ValaForStatementPrivate;

/**
 * Represents a for iteration statement in the source code.
 */
struct _ValaForStatement {
	ValaCodeNode parent_instance;
	ValaForStatementPrivate * priv;
};

struct _ValaForStatementClass {
	ValaCodeNodeClass parent_class;
};


ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init);
GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self);
void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter);
GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self);
ValaExpression* vala_for_statement_get_condition (ValaForStatement* self);
void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value);
ValaBlock* vala_for_statement_get_body (ValaForStatement* self);
void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value);
GType vala_for_statement_get_type (void);


G_END_DECLS

#endif

==> vala-0.5.1.tar.gz: vala-0.5.1/vala/valaforstatement.h <==
/* valaforstatement.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAFORSTATEMENT_H__
#define __VALA_VALAFORSTATEMENT_H__

#include <glib.h>
#include <glib-object.h>
#include <gee/list.h>
#include <vala/valacodenode.h>
#include <vala/valastatement.h>

G_BEGIN_DECLS


#define VALA_TYPE_FOR_STATEMENT (vala_for_statement_get_type ())
#define VALA_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatement))
#define VALA_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))
#define VALA_IS_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FOR_STATEMENT))
#define VALA_IS_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FOR_STATEMENT))
#define VALA_FOR_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))

typedef struct _ValaForStatementPrivate ValaForStatementPrivate;

/**
 * Represents a for iteration statement in the source code.
 */
struct _ValaForStatement {
	ValaCodeNode parent_instance;
	ValaForStatementPrivate * priv;
};

struct _ValaForStatementClass {
	ValaCodeNodeClass parent_class;
};


ValaForStatement* vala_for_statement_construct (GType object_type, ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init);
GeeList* vala_for_statement_get_initializer (ValaForStatement* self);
void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter);
GeeList* vala_for_statement_get_iterator (ValaForStatement* self);
ValaExpression* vala_for_statement_get_condition (ValaForStatement* self);
void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value);
ValaBlock* vala_for_statement_get_body (ValaForStatement* self);
void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value);
GType vala_for_statement_get_type (void);


G_END_DECLS

#endif
